@@ -1,5 +1,5 @@
 Clazz.declarePackage ("J.shapespecial");
-Clazz.load (["J.shape.AtomShape", "JU.AU", "$.BS", "$.P3", "$.V3"], "J.shapespecial.Polyhedra", ["java.lang.Boolean", "$.Float", "java.util.Arrays", "$.Hashtable", "JU.Lst", "$.Measure", "$.P4", "$.PT", "$.SB", "J.api.Interface", "J.c.PAL", "J.shapespecial.Polyhedron", "JU.BSUtil", "$.C", "$.Logger", "$.Normix"], function () {
+Clazz.load (["J.shape.AtomShape", "JU.AU", "$.BS", "$.P3", "$.V3"], "J.shapespecial.Polyhedra", ["java.lang.Boolean", "$.Float", "java.util.Arrays", "$.Hashtable", "JU.Lst", "$.Measure", "$.P4", "$.PT", "$.SB", "J.api.Interface", "J.c.PAL", "JS.SV", "J.shapespecial.Polyhedron", "JU.BSUtil", "$.C", "$.Logger", "$.Normix"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.otherAtoms = null;
 this.normalsT = null;
@@ -143,7 +143,7 @@ this.bondedOnly = true;
 return;
 }if ("info" === propertyName) {
 this.info = value;
-this.centers = (this.info.containsKey ("center") ? null : JU.BSUtil.newAndSetBit (this.info.get ("atomIndex").intValue));
+this.centers = (this.info.containsKey ("center") ? null : JU.BSUtil.newAndSetBit ((this.info.get ("atomIndex")).intValue));
 this.iHaveCenterBitSet = (this.centers != null);
 return;
 }if ("delete" === propertyName) {
@@ -488,7 +488,8 @@ if (this.thisID != null) {
 if (JU.PT.isWild (this.thisID)) return;
 if (this.center != null) p = this.validatePolyhedron (this.center, this.nPoints);
 } else if (this.info != null && this.info.containsKey ("id")) {
-this.thisID = this.info.get ("id").asString ();
+var o = this.info.get ("id");
+this.thisID = (Clazz.instanceOf (o, JS.SV) ? (o).asString () : o.toString ());
 p =  new J.shapespecial.Polyhedron ().setInfo (this.vwr, this.info, this.vwr.ms.at);
 }if (p != null) {
 this.addPolyhedron (p);
