@@ -1,8 +1,8 @@
 Clazz.declarePackage ("JS");
 Clazz.load (["JU.BS", "$.Lst", "$.V3"], "JS.CIPChirality", ["java.util.Arrays", "$.Hashtable", "JU.Measure", "$.P4", "$.PT", "JU.BSUtil", "$.Elements", "$.Logger", "JV.JC"], function () {
 c$ = Clazz.decorateAsClass (function () {
-this.isRule4TEST = false;
-this.ptID = 0;
+this.bsNeedRule = null;
+this.ptIDLogger = 0;
 this.root = null;
 this.currentRule = 1;
 this.lstSmallRings = null;
@@ -12,15 +12,14 @@ this.bsAzacyclic = null;
 this.vNorm = null;
 this.vNorm2 = null;
 this.vTemp = null;
-this.rule1bOption = 1;
 this.setAuxiliary = false;
-this.rootRule = 0;
 if (!Clazz.isClassDefined ("JS.CIPChirality.CIPAtom")) {
 JS.CIPChirality.$CIPChirality$CIPAtom$ ();
 }
 Clazz.instantialize (this, arguments);
 }, JS, "CIPChirality");
 Clazz.prepareFields (c$, function () {
+this.bsNeedRule =  new JU.BS ();
 this.lstSmallRings =  new JU.Lst ();
 this.vNorm =  new JU.V3 ();
 this.vNorm2 =  new JU.V3 ();
@@ -36,7 +35,7 @@ function () {
 });
 Clazz.defineMethod (c$, "init", 
  function () {
-this.ptID = 0;
+this.ptIDLogger = 0;
 this.lstSmallRings.clear ();
 this.bsKekuleAmbiguous = null;
 this.bsAtropisomeric =  new JU.BS ();
@@ -58,7 +57,7 @@ var haveAlkenes = this.preFilterAtomList (atoms, bsToDo);
 for (var i = bsToDo.nextSetBit (0); i >= 0; i = bsToDo.nextSetBit (i + 1)) {
 var a = atoms[i];
 a.setCIPChirality (0);
-this.ptID = 0;
+this.ptIDLogger = 0;
 var c = this.getAtomChiralityLimited (a, null, null);
 a.setCIPChirality (c == 0 ? 3 : c | ((this.currentRule - 1) << 5));
 }
@@ -193,7 +192,7 @@ if (!this.isFirstRow (other)) return -1;
 if (b != null && (other !== b || b.getCovalentBondCount () == 1)) {
 return -1;
 }}
-return 5;
+return 13;
 }, "JU.SimpleNode,JU.SimpleNode");
 Clazz.defineMethod (c$, "isFirstRow", 
 function (a) {
@@ -329,9 +328,10 @@ cipAtom.htPathPoints = (cipAtom.parent = Clazz.innerTypeInstance (JS.CIPChiralit
 } else {
 if (!(this.root = cipAtom = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (atom, null, false, false, false)).isSP3) {
 return 0;
-}}if (cipAtom.setNode ()) {
+}this.bsNeedRule.clearAll ();
+this.bsNeedRule.set (1);
+}if (cipAtom.setNode ()) {
 for (this.currentRule = 1; this.currentRule <= 9; this.currentRule++) {
-this.rootRule = this.currentRule;
 if (JU.Logger.debugging) JU.Logger.info ("-Rule " + this.getRuleName (this.currentRule) + " CIPChirality for " + cipAtom + "-----");
 switch (this.currentRule) {
 case 4:
@@ -339,18 +339,20 @@ cipAtom.rootRule4bQueue =  new JU.Lst ();
 cipAtom.createAuxiliaryDescriptors (null, null);
 break;
 case 5:
-if (cipAtom.rule4Type == 0) {
+if (!this.bsNeedRule.get (5)) {
 this.currentRule = 8;
 continue;
 }case 6:
 case 7:
 cipAtom.sortSubstituents (-2147483648);
+case 8:
+this.bsNeedRule.set (this.currentRule);
 break;
 case 9:
-rs = cipAtom.setupRule6 (false);
-if (rs == 0) continue;
+this.bsNeedRule.setBitTo (9, ((rs = cipAtom.setupRule6 (false)) != 0));
 break;
 }
+if (!this.bsNeedRule.get (this.currentRule)) continue;
 var nPrioritiesPrev = cipAtom.nPriorities;
 if (rs == 0 && cipAtom.sortSubstituents (0)) {
 if (JU.Logger.debugging && cipAtom.h1Count < 2) {
@@ -394,7 +396,7 @@ var btop = this.getAtomChiralityLimited (null, b2, pb) - 1;
 var ruleB = this.currentRule;
 var c = (atop >= 0 && btop >= 0 ? this.getEneChirality (b2.atoms[btop], b2, a1, a1.atoms[atop], isAxial, true) : 0);
 if (c != 0 && (isAxial || !this.bsAtropisomeric.get (a.getIndex ()) && !this.bsAtropisomeric.get (b.getIndex ()))) {
-if (isAxial && ((ruleA == 8) != (ruleB == 8))) {
+if (isAxial && ((ruleA >= 8) != (ruleB >= 8))) {
 c |= 8;
 }a.setCIPChirality (c | ((ruleA - 1) << 5));
 b.setCIPChirality (c | ((ruleB - 1) << 5));
@@ -403,7 +405,7 @@ if (JU.Logger.debugging) JU.Logger.info (a + "-" + b + " " + JV.JC.getCIPChirali
 }, "JU.SimpleNode,JU.SimpleNode,JU.SimpleNode,JU.SimpleNode,~B");
 Clazz.defineMethod (c$, "getEneChirality", 
 function (top1, end1, end2, top2, isAxial, allowPseudo) {
-return (top1 == null || top2 == null || top1.atom == null || top2.atom == null ? 0 : isAxial ? (this.isPos (top1, end1, end2, top2) ? 18 : 17) : (this.isCis (top1, end1, end2, top2) ? 5 : 6));
+return (top1 == null || top2 == null || top1.atom == null || top2.atom == null ? 0 : isAxial ? (this.isPos (top1, end1, end2, top2) ? 18 : 17) : (this.isCis (top1, end1, end2, top2) ? 13 : 14));
 }, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,~B,~B");
 Clazz.defineMethod (c$, "isCis", 
 function (a, b, c, d) {
@@ -460,9 +462,8 @@ this.rootRule4bQueue = null;
 this.isChiralPath = false;
 this.rule4Type = 0;
 this.bsTemp = null;
-this.reverseRule2 = false;
 this.rule4Ref = 0;
-this.bsRS = null;
+this.listRS = null;
 this.newAtoms = null;
 this.rule6refIndex = -1;
 Clazz.instantialize (this, arguments);
@@ -477,7 +478,7 @@ function () {
 Clazz.defineMethod (c$, "setupRule6", 
 function (a) {
 if (this.nPriorities > 2 || (a ? this.countDuplicates (this.atomIndex) : this.nRootDuplicates) <= 2) return 0;
-var b = (this.priorities[3] != 1 && !a);
+var b = (this.nPriorities == 1 && !a);
 this.b$["JS.CIPChirality"].root.rule6refIndex = this.atoms[this.priorities[2]].atomIndex;
 if (b) this.saveRestorePriorities (false);
 this.sortSubstituents (-2147483648);
@@ -518,12 +519,13 @@ return b;
 }, "~N");
 Clazz.defineMethod (c$, "create", 
 function (a, b, c, d, e) {
-this.id = ++this.b$["JS.CIPChirality"].ptID;
+this.id = ++this.b$["JS.CIPChirality"].ptIDLogger;
 this.parent = b;
 if (a == null) return this;
 this.isAlkene = c;
 this.atom = a;
 this.atomIndex = a.getIndex ();
+if (a.getIsotopeNumber () > 0) this.b$["JS.CIPChirality"].bsNeedRule.set (3);
 this.isKekuleAmbiguous = (this.b$["JS.CIPChirality"].bsKekuleAmbiguous != null && this.b$["JS.CIPChirality"].bsKekuleAmbiguous.get (this.atomIndex));
 this.elemNo = (d && this.isKekuleAmbiguous ? b.getKekuleElementNumber () : a.getElementNumber ());
 this.bondCount = a.getCovalentBondCount ();
@@ -534,34 +536,30 @@ this.htPathPoints =  new java.util.Hashtable ();
 } else if (b != null) {
 this.htPathPoints = (b.htPathPoints).clone ();
 }this.bsPath = (b == null ?  new JU.BS () : JU.BSUtil.copy (b.bsPath));
-this.multipleBondDuplicate = d;
+this.isDuplicate = this.multipleBondDuplicate = d;
+if (d) this.b$["JS.CIPChirality"].bsNeedRule.set (4);
 this.rootDistance = this.sphere;
 if (b == null) {
 this.bsPath.set (this.atomIndex);
-} else if (this.multipleBondDuplicate && (this.b$["JS.CIPChirality"].rule1bOption == 4 && this.isKekuleAmbiguous || this.b$["JS.CIPChirality"].rule1bOption == 2)) {
-} else if (this.multipleBondDuplicate && this.b$["JS.CIPChirality"].rule1bOption == 1) {
+} else if (this.multipleBondDuplicate) {
 this.rootDistance--;
-} else if (a === this.b$["JS.CIPChirality"].root.atom) {
-d = true;
-this.rootDistance = 0;
-this.b$["JS.CIPChirality"].root.nRootDuplicates++;
 } else if (this.bsPath.get (this.atomIndex)) {
-d = true;
-this.rootDistance = (e ? b.sphere : this.htPathPoints.get (Integer.$valueOf (this.atomIndex)).intValue ());
-} else {
+this.b$["JS.CIPChirality"].bsNeedRule.setBitTo (2, (this.isDuplicate = true));
+if ((this.rootDistance = (a === this.b$["JS.CIPChirality"].root.atom ? 0 : e ? b.sphere : this.htPathPoints.get (Integer.$valueOf (this.atomIndex)).intValue ())) == 0) {
+this.b$["JS.CIPChirality"].root.nRootDuplicates++;
+}} else {
 this.bsPath.set (this.atomIndex);
 this.htPathPoints.put (Integer.$valueOf (this.atomIndex), Integer.$valueOf (this.rootDistance));
-}this.isDuplicate = d;
-if (JU.Logger.debuggingHigh) {
+}if (JU.Logger.debuggingHigh) {
 if (this.sphere < 50) this.myPath = (b != null ? b.myPath + "-" : "") + this;
 JU.Logger.info ("new CIPAtom " + this.myPath);
 }return this;
 }, "JU.SimpleNode,JS.CIPChirality.CIPAtom,~B,~B,~B");
 Clazz.defineMethod (c$, "getMass", 
  function () {
-if (this.mass == -1 && (this.mass = this.atom.getMass ()) == Clazz.floatToInt (this.mass)) {
-if (this.isType (";4He;16O;52Cr;96Mo;175Lu;")) this.reverseRule2 = true;
- else if (this.elemNo > 92 || this.isType (";9Be;19F;23Na;27Al;31P;45Sc;55Mn;59Co;75As;89Y;93Nb;98Tc;103Rh;127I;133Cs;141Pr;145Pm;159Tb;165Ho;169Tm;197Au;209Bi;209Po;210At;222Rn;223Fr;226Ra;227Ac;231Pa;232Th;and all > U (atomno > 92)")) this.mass = JU.Elements.getAtomicMass (Clazz.floatToInt (this.elemNo));
+if (this.mass == -1) {
+if (this.isDuplicate || (this.mass = this.atom.getMass ()) != Clazz.floatToInt (this.mass) || this.isType (";9Be;19F;23Na;27Al;31P;45Sc;55Mn;59Co;75As;89Y;93Nb;98Tc;103Rh;127I;133Cs;141Pr;145Pm;159Tb;165Ho;169Tm;197Au;209Bi;209Po;210At;222Rn;223Fr;226Ra;227Ac;231Pa;232Th;and all > U (atomno > 92)")) return (this.mass == -1 ? this.mass = JU.Elements.getAtomicMass (Clazz.floatToInt (this.elemNo)) : this.mass);
+if (this.isType (";16O;52Cr;96Mo;175Lu;")) this.mass -= 0.1;
 }return this.mass;
 });
 Clazz.defineMethod (c$, "isType", 
@@ -688,21 +686,21 @@ var h = this.atoms[g];
 if (h.nextChiralBranch != null) {
 h.nextChiralBranch.sortSubstituents (a);
 }}
-for (var h = 0; h < 4; h++) {
+for (var h = 0; h < 3; h++) {
 var i = this.atoms[h];
-for (var j = h + 1; j < 4; j++) {
-var k = this.atoms[e = j];
-switch (i.atom == null ? 1 : k.atom == null ? -1 : this.priorities[h] < this.priorities[j] ? -1 : this.priorities[j] < this.priorities[h] ? 1 : (f = this.checkPriority (i, k)) != 0 ? f : b ? -2147483648 : this.sign (i.breakTie (k, a + 1))) {
+var j = i.isDuplicate && this.b$["JS.CIPChirality"].currentRule > 2;
+for (var k = h + 1; k < 4; k++) {
+var l = this.atoms[e = k];
+switch (l.atom == null || this.priorities[h] < this.priorities[k] ? -1 : j || i.atom == null || this.priorities[k] < this.priorities[h] ? 1 : (f = i.checkCurrentRule (l)) != 0 && f != -2147483648 || b ? f : this.sign (i.breakTie (l, a + 1))) {
 case 1:
 e = h;
 case -1:
 d[e]++;
-break;
-case 0:
 case -2147483648:
-break;
-}
+case 0:
 c[e]++;
+continue;
+}
 }
 }
 this.bsTemp.clearAll ();
@@ -732,125 +730,114 @@ return ".....................".substring (0, Math.min (20, this.sphere));
 });
 Clazz.defineMethod (c$, "breakTie", 
  function (a, b) {
-if (this.isDuplicate && a.isDuplicate && this.atom === a.atom && this.rootDistance == a.rootDistance) return 0;
-var c = this.checkIsDuplicate (a);
-if (c != 0) return c * (b + 1);
-if (!this.setNode () || !a.setNode () || this.isTerminal && a.isTerminal || this.isDuplicate && a.isDuplicate) return 0;
-if (this.isTerminal != a.isTerminal) return (this.isTerminal ? 1 : -1) * (b + 1);
-if ((c = this.compareShallowly (a, b)) != 0) {
-return c;
-}this.sortSubstituents (b);
+if (this.isDuplicate && (this.b$["JS.CIPChirality"].currentRule > 2 || a.isDuplicate && this.atom === a.atom && this.rootDistance == a.rootDistance) || !this.setNode () || !a.setNode () || this.isTerminal && a.isTerminal || this.isDuplicate && a.isDuplicate) return 0;
+if (this.isTerminal != a.isTerminal) return (this.isTerminal ? 1 : -1) * (b + (a.isDuplicate || this.isDuplicate ? 0 : 1));
+var c = (this.b$["JS.CIPChirality"].currentRule > 1 ? 0 : this.unlikeDuplicates (a));
+if (c != 0) {
+return c * (b + 1);
+}for (var d = 0; d < this.nAtoms; d++) if ((c = this.atoms[d].checkCurrentRule (a.atoms[d])) != 0) return c * (b + 1);
+
+this.sortSubstituents (b);
 a.sortSubstituents (b);
-var d = (this.nAtoms == 0 ? 1 : 0);
-var e = 2147483647;
-for (var f = 0; f < this.nAtoms; f++) {
-var g = this.atoms[f];
-var h = a.atoms[f];
-if ((c = g.breakTie (h, b + 1)) != 0) {
-var i = Math.abs (c);
-if (i < e) {
-e = i;
-d = c;
-}}}
-return d;
-}, "JS.CIPChirality.CIPAtom,~N");
-Clazz.defineMethod (c$, "compareShallowly", 
- function (a, b) {
-for (var c = 0; c < this.nAtoms; c++) {
-var d = this.atoms[c];
-var e = a.atoms[c];
-var f = d.checkCurrentRule (e);
-switch (f) {
-case -2147483648:
-if (this.b$["JS.CIPChirality"].currentRule != 6) continue;
-return -2147483648;
-case 0:
-continue;
-default:
-return f * (b + 1);
-}
-}
-return 0;
+var e = 0;
+for (var f = 0, g, h = 2147483647; f < this.nAtoms; f++) {
+if ((c = this.atoms[f].breakTie (a.atoms[f], b + 1)) != 0 && (g = Math.abs (c)) < h) {
+h = g;
+e = c;
+}}
+return e;
 }, "JS.CIPChirality.CIPAtom,~N");
 Clazz.overrideMethod (c$, "compareTo", 
 function (a) {
 var b;
-return (a == null ? -1 : (this.atom == null) != (a.atom == null) ? (this.atom == null ? 1 : -1) : (b = this.checkRule1a (a)) != 0 ? b : (b = this.checkIsDuplicate (a)) != 0 ? b : this.isDuplicate && (b = this.checkRule1b (a)) != 0 ? b : this.checkRule2 (a));
+return (a == null ? -1 : (this.atom == null) != (a.atom == null) ? (this.atom == null ? 1 : -1) : (b = this.compareRule1a (a)) != 0 ? b : (b = this.unlikeDuplicates (a)) != 0 || !this.isDuplicate ? b : this.compareRule1b (a));
 }, "JS.CIPChirality.CIPAtom");
-Clazz.defineMethod (c$, "checkPriority", 
- function (a, b) {
-var c;
-return ((a.atom == null) != (b.atom == null) ? (a.atom == null ? 1 : -1) : (c = a.checkCurrentRule (b)) == -2147483648 ? 0 : c);
-}, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom");
-Clazz.defineMethod (c$, "checkIsDuplicate", 
- function (a) {
-return a.isDuplicate == this.isDuplicate ? 0 : a.isDuplicate ? -1 : 1;
-}, "JS.CIPChirality.CIPAtom");
-Clazz.defineMethod (c$, "sortByRule", 
+Clazz.defineMethod (c$, "auxSort", 
  function (a) {
 var b = this.b$["JS.CIPChirality"].currentRule;
 this.b$["JS.CIPChirality"].currentRule = a;
 var c = this.b$["JS.CIPChirality"].root.rule6refIndex;
-var d = (a == 9 ? this.setupRule6 (true) != 0 : this.sortSubstituents (0));
+var d = this.b$["JS.CIPChirality"].root.nRootDuplicates;
+var e = (a == 9 ? this.setupRule6 (true) != 0 : this.sortSubstituents (0));
+this.b$["JS.CIPChirality"].root.nRootDuplicates = d;
 this.b$["JS.CIPChirality"].root.rule6refIndex = c;
 this.b$["JS.CIPChirality"].currentRule = b;
-return d;
+return e;
 }, "~N");
 Clazz.defineMethod (c$, "checkCurrentRule", 
  function (a) {
 switch (this.b$["JS.CIPChirality"].currentRule) {
 default:
 case 1:
-return this.checkRule1a (a);
+return this.compareRule1a (a);
 case 2:
-return this.checkRule1b (a);
+return this.compareRule1b (a);
 case 3:
-return this.checkRule2 (a);
+return this.compareRule2 (a);
 case 4:
-return this.checkRule3 (a);
+return this.compareRule3 (a);
 case 5:
-return this.checkRules4ac (a, " sr SR PM");
-case 7:
-return this.checkRules4ac (a, " s r p m");
+return this.compareRules4ac (a, " sr SR PM");
+case 99:
+return this.compareRule4bRef (a);
 case 6:
 case 8:
-return this.checkRule4b5 (a);
+return (this.isTerminal || a.isTerminal ? 0 : this.compareRule4b5Root (a));
+case 7:
+return this.compareRules4ac (a, " s r p m");
 case 9:
-return this.checkRule6 (a);
-case 99:
-return this.rule4Type == a.rule4Type ? 0 : this.rule4Type == this.b$["JS.CIPChirality"].root.rule4Ref ? -1 : 1;
+return this.compareRule6 (a);
 }
 }, "JS.CIPChirality.CIPAtom");
-Clazz.defineMethod (c$, "checkRule1a", 
+Clazz.defineMethod (c$, "unlikeDuplicates", 
+ function (a) {
+return a.isDuplicate == this.isDuplicate ? 0 : this.isDuplicate ? 1 : -1;
+}, "JS.CIPChirality.CIPAtom");
+Clazz.defineMethod (c$, "compareRule1a", 
  function (a) {
 return a.atom == null ? -1 : this.atom == null ? 1 : a.elemNo < this.elemNo ? -1 : a.elemNo > this.elemNo ? 1 : 0;
 }, "JS.CIPChirality.CIPAtom");
-Clazz.defineMethod (c$, "checkRule1b", 
+Clazz.defineMethod (c$, "compareRule1b", 
  function (a) {
-return a.isDuplicate != this.isDuplicate ? 0 : this.b$["JS.CIPChirality"].rule1bOption == 3 && (this.parent.isAlkene || a.parent.isAlkene) ? 0 : Integer.compare (this.rootDistance, a.rootDistance);
+return a.isDuplicate != this.isDuplicate ? 0 : Integer.compare (this.rootDistance, a.rootDistance);
 }, "JS.CIPChirality.CIPAtom");
-Clazz.defineMethod (c$, "checkRule2", 
+Clazz.defineMethod (c$, "compareRule2", 
  function (a) {
-return (a.getMass () == this.getMass () ? 0 : (this.reverseRule2 || a.reverseRule2) == (a.mass > this.mass) ? -1 : 1);
+return (this.getMass () == a.getMass () ? 0 : this.mass > a.mass ? -1 : 1);
 }, "JS.CIPChirality.CIPAtom");
-Clazz.defineMethod (c$, "checkRule3", 
+Clazz.defineMethod (c$, "compareRule3", 
  function (a) {
 return this.isDuplicate || a.isDuplicate || !this.parent.isAlkeneAtom2 || !a.parent.isAlkeneAtom2 || !this.parent.alkeneParent.isEvenEne || !a.parent.alkeneParent.isEvenEne || this.parent === a.parent ? 0 : Integer.compare (this.parent.auxEZ, a.parent.auxEZ);
 }, "JS.CIPChirality.CIPAtom");
-Clazz.defineMethod (c$, "checkRules4ac", 
+Clazz.defineMethod (c$, "compareRules4ac", 
  function (a, b) {
 if (this.isTerminal || this.isDuplicate) return 0;
 var c = b.indexOf (this.auxChirality);
 var d = b.indexOf (a.auxChirality);
 return (c > d + 1 ? -1 : d > c + 1 ? 1 : 0);
 }, "JS.CIPChirality.CIPAtom,~S");
-Clazz.defineMethod (c$, "checkRule4b5", 
+Clazz.defineMethod (c$, "compareRule4bRef", 
  function (a) {
-if (this.isTerminal || a.isTerminal) return 0;
-var b = this.getBS4b5 ();
-var c = this.compareLikeUnlike (b, a.getBS4b5 ());
-return (c == null ? -2147483648 : c === b ? -1 : 1);
+return this.rule4Type == a.rule4Type ? 0 : this.rule4Type == this.b$["JS.CIPChirality"].root.rule4Ref ? -1 : 1;
 }, "JS.CIPChirality.CIPAtom");
+Clazz.defineMethod (c$, "compareRule4b5Root", 
+ function (a) {
+var b = this.getBestList ();
+var c = a.getBestList ();
+var d = this.compareLikeUnlike (b, c);
+return (d == null ? -2147483648 : d === b ? -1 : 1);
+}, "JS.CIPChirality.CIPAtom");
+Clazz.defineMethod (c$, "getBestList", 
+ function () {
+if (this.b$["JS.CIPChirality"].currentRule == 8) return this.listRS[0];
+if (this.listRS == null) {
+this.listRS =  new Array (2);
+this.rankAndRead (this.listRS[0] =  new JU.BS (), 1);
+this.rankAndRead (this.listRS[1] =  new JU.BS (), 2);
+}if (JU.Logger.debugging) JU.Logger.info ("getBS4b5 " + this + " " + this.listRS[0] + this.listRS[1]);
+var a = this.compareLikeUnlike (this.listRS[0], this.listRS[1]);
+return (a == null ? this.listRS[0] : a);
+});
 Clazz.defineMethod (c$, "compareLikeUnlike", 
  function (a, b) {
 var c = b.clone ();
@@ -858,26 +845,14 @@ c.xor (a);
 var d = c.nextSetBit (0);
 return (d < 0 ? null : a.get (d) ? a : b);
 }, "JU.BS,JU.BS");
-Clazz.defineMethod (c$, "getBS4b5", 
- function () {
-if (this.b$["JS.CIPChirality"].currentRule == 8) return this.bsRS[0];
-if (this.bsRS == null) {
-this.bsRS =  new Array (2);
-this.getBS4bBreadth (1);
-this.getBS4bBreadth (2);
-}if (JU.Logger.debugging) JU.Logger.info ("getBS4b5 " + this + " " + this.bsRS[0] + this.bsRS[1]);
-var a = this.compareLikeUnlike (this.bsRS[0], this.bsRS[1]);
-return (a == null ? this.bsRS[0] : a);
-});
-Clazz.defineMethod (c$, "getBS4bBreadth", 
- function (a) {
-this.b$["JS.CIPChirality"].root.rule4Ref = a;
+Clazz.defineMethod (c$, "rankAndRead", 
+ function (a, b) {
+this.b$["JS.CIPChirality"].root.rule4Ref = b;
 this.b$["JS.CIPChirality"].currentRule = 99;
 this.sortSubstituents (0);
 this.b$["JS.CIPChirality"].root.rootRule4bQueue.clear ();
 this.b$["JS.CIPChirality"].root.rootRule4bQueue.addLast (this);
-var b = this.bsRS[a - 1] =  new JU.BS ();
-if (this.rule4Type == a) b.set (0);
+if (this.rule4Type == b) a.set (0);
 var c = (this.rule4Type == 0 ? 0 : 1);
 while (this.b$["JS.CIPChirality"].root.rootRule4bQueue.size () != 0) {
 var d = this.b$["JS.CIPChirality"].root.rootRule4bQueue.removeItemAt (0);
@@ -888,13 +863,13 @@ var g = e[f];
 if (g == null || g.atom == null || g.isTerminal || g.isDuplicate) continue;
 this.b$["JS.CIPChirality"].root.rootRule4bQueue.addLast (g);
 if (g.rule4Type == 0) continue;
-if (g.rule4Type == a) b.set (c);
+if (g.rule4Type == b) a.set (c);
 c++;
 }
 }
 this.b$["JS.CIPChirality"].currentRule = 6;
-}, "~N");
-Clazz.defineMethod (c$, "checkRule6", 
+}, "JU.BS,~N");
+Clazz.defineMethod (c$, "compareRule6", 
  function (a) {
 return ((this.atomIndex == this.b$["JS.CIPChirality"].root.rule6refIndex) == (a.atomIndex == this.b$["JS.CIPChirality"].root.rule6refIndex) ? 0 : this.atomIndex == this.b$["JS.CIPChirality"].root.rule6refIndex ? -1 : 1);
 }, "JS.CIPChirality.CIPAtom");
@@ -912,7 +887,7 @@ var d = a.clone ();
 if (d.parent !== b) d.addReturnPath (b, a);
 var e;
 for (var f = 1; f <= 9; f++) {
-if (d.sortByRule (f)) {
+if (d.auxSort (f)) {
 for (var g = 0; g < 4; g++) {
 e = d.atoms[g];
 if (!e.multipleBondDuplicate) {
@@ -1004,25 +979,26 @@ break;
 }
 if (this.isAlkene) {
 if (this.alkeneChild != null) {
-if (!this.isEvenEne || (this.auxEZ == 7 || this.auxEZ == -1) && !this.isKekuleAmbiguous && this.alkeneChild.bondCount >= 2) {
+if (!this.isEvenEne || (this.auxEZ == 15 || this.auxEZ == -1) && !this.isKekuleAmbiguous && this.alkeneChild.bondCount >= 2) {
 var m = (this.isEvenEne ?  Clazz.newIntArray (1, 0) : null);
 e = this.getAuxEneWinnerChirality (this, this.alkeneChild, !this.isEvenEne, m);
 if (e == 0) {
-this.auxEZ = this.alkeneChild.auxEZ = 7;
+this.auxEZ = this.alkeneChild.auxEZ = 15;
 } else {
+c = true;
 if (m != null && m[0] != 8) {
 this.auxEZ = this.alkeneChild.auxEZ = e;
-if (JU.Logger.debuggingHigh) JU.Logger.info ("alkene type " + this + " " + (this.auxEZ == 6 ? "E" : "Z"));
+if (JU.Logger.debuggingHigh) JU.Logger.info ("alkene type " + this + " " + (this.auxEZ == 14 ? "E" : "Z"));
 } else if (!l) {
 switch (e) {
 case 17:
-case 5:
+case 13:
 e = 1;
 d = 'R';
 c = true;
 break;
 case 18:
-case 6:
+case 14:
 e = 2;
 d = 'S';
 c = true;
@@ -1035,7 +1011,7 @@ var m = this.clone ();
 if (m.setNode ()) {
 m.addReturnPath (null, this);
 var n = 1;
-for (; n <= 9; n++) if ((!h || n < 5 || n > 8) && m.sortByRule (n)) break;
+for (; n <= 9; n++) if ((!h || n < 5 || n > 8) && m.auxSort (n)) break;
 
 if (n > 9) {
 d = '~';
@@ -1049,7 +1025,7 @@ d = (d == 'R' ? 'r' : d == 'S' ? 's' : '~');
 this.rule4Type = e;
 }}}this.auxChirality = d;
 }if (this.b$["JS.CIPChirality"].setAuxiliary && this.auxChirality != '~') this.atom.setCIPChirality (JV.JC.getCIPChiralityCode (this.auxChirality));
-if (a == null) this.rule4Type = f;
+if (a == null) this.b$["JS.CIPChirality"].bsNeedRule.setBitTo (5, f > 0);
 if (JU.Logger.debugging && d != '~') {
 JU.Logger.info ("creating aux " + d + " for " + this + " = " + this.myPath);
 }return (this.isChiralPath = c);
@@ -1096,7 +1072,7 @@ if (Clazz.exceptionOf (e, CloneNotSupportedException)) {
 throw e;
 }
 }
-a.id = this.b$["JS.CIPChirality"].ptID++;
+a.id = this.b$["JS.CIPChirality"].ptIDLogger++;
 a.atoms =  new Array (4);
 for (var b = 0; b < 4; b++) a.atoms[b] = this.atoms[b];
 
@@ -1105,7 +1081,7 @@ a.htPathPoints = this.htPathPoints;
 a.alkeneParent = null;
 a.auxEZ = -1;
 a.rule4Type = 0;
-a.bsRS = null;
+a.listRS = null;
 return a;
 });
 Clazz.overrideMethod (c$, "toString", 
@@ -1116,7 +1092,7 @@ c$ = Clazz.p0p ();
 };
 Clazz.defineStatics (c$,
 "RULE_2_nXX_EQ_XX", ";9Be;19F;23Na;27Al;31P;45Sc;55Mn;59Co;75As;89Y;93Nb;98Tc;103Rh;127I;133Cs;141Pr;145Pm;159Tb;165Ho;169Tm;197Au;209Bi;209Po;210At;222Rn;223Fr;226Ra;227Ac;231Pa;232Th;and all > U (atomno > 92)",
-"RULE_2_nXX_REV_XX", ";4He;16O;52Cr;96Mo;175Lu;",
+"RULE_2_REDUCE_ISOTOPE_MASS_NUMBER", ";16O;52Cr;96Mo;175Lu;",
 "NO_CHIRALITY", 0,
 "TIED", 0,
 "A_WINS", -1,
@@ -1127,10 +1103,10 @@ Clazz.defineStatics (c$,
 "STEREO_S", 2,
 "STEREO_M", 17,
 "STEREO_P", 18,
-"STEREO_Z", 5,
-"STEREO_E", 6,
+"STEREO_Z", 13,
+"STEREO_E", 14,
 "STEREO_BOTH_RS", 3,
-"STEREO_BOTH_EZ", 7,
+"STEREO_BOTH_EZ", 15,
 "RULE_1a", 1,
 "RULE_1b", 2,
 "RULE_2", 3,
@@ -1141,16 +1117,8 @@ Clazz.defineStatics (c$,
 "RULE_5", 8,
 "RULE_6", 9,
 "RULE_RS", 99,
-"prefixString", "..........");
-c$.zero = c$.prototype.zero = Integer.$valueOf (0);
-Clazz.defineStatics (c$,
 "ruleNames",  Clazz.newArray (-1, ["", "1a", "1b", "2", "3", "4a", "4b", "4c", "5", "6"]),
 "TRIGONALITY_MIN", 0.2,
 "MAX_PATH", 50,
-"SMALL_RING_MAX", 7,
-"RULE_1b_TEST_OPTION_0_UNCHANGED", 0,
-"RULE_1b_TEST_OPTION_A_PARENT", 1,
-"RULE_1b_TEST_OPTION_B_SELF", 2,
-"RULE_1b_TEST_OPTION_C_NONE", 3,
-"RULE_1b_TEST_OPTION_D_SELF_KEKULE", 4);
+"SMALL_RING_MAX", 7);
 });
